Function lighting
pub fn lighting(
mul: impl Into<Color>,
add: impl Into<Color>,
) -> Option<RCHandle<SkColorFilter>>Expand description
Create a color filter that multiplies the RGB channels by one color, and then adds a second color, pinning the result for each component to [0..255]. The alpha components of the mul and add arguments are ignored.