Function table_argb

pub fn table_argb<'a>(
    table_a: impl Into<Option<&'a [u8; 256]>>,
    table_r: impl Into<Option<&'a [u8; 256]>>,
    table_g: impl Into<Option<&'a [u8; 256]>>,
    table_b: impl Into<Option<&'a [u8; 256]>>,
) -> Option<RCHandle<SkColorFilter>>
Create a table color filter, with a different table for each component [A, R, G, B]. If a given table is None, then it is treated as identity, with the component left unchanged. If a table is not None, then its contents are copied into the filter.